Enum std::io::SeekFromStable
[-] [+]
[src]
pub enum SeekFrom {
Start(u64),
End(i64),
Current(i64),
}Enumeration of possible methods to seek within an I/O object.
pub enum SeekFrom {
Start(u64),
End(i64),
Current(i64),
}Enumeration of possible methods to seek within an I/O object.
impl Debug for SeekFromimpl Clone for SeekFromfn clone(&self) -> SeekFromfn clone_from(&mut self, source: &Self)impl Eq for SeekFromimpl PartialEq for SeekFromimpl Copy for SeekFrom
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).