Function std::io::copyStable
[-] [+]
[src]
pub fn copy<R: Read, W: Write>(r: &mut R, w: &mut W) -> Result<u64>
Copies the entire contents of a reader into a writer.
This function will continuously read data from r and then write it into
w in a streaming fashion until r returns EOF.
On success the total number of bytes that were copied from r to w is
returned.
Errors
This function will return an error immediately if any call to read or
write returns an error. All instances of ErrorKind::Interrupted are
handled by this function and the underlying operation is retried.